summaryrefslogtreecommitdiff
path: root/mpn/m88k/mul_1.s
diff options
context:
space:
mode:
Diffstat (limited to 'mpn/m88k/mul_1.s')
-rw-r--r--mpn/m88k/mul_1.s6
1 files changed, 3 insertions, 3 deletions
diff --git a/mpn/m88k/mul_1.s b/mpn/m88k/mul_1.s
index 26626bf95..bd1bff2b8 100644
--- a/mpn/m88k/mul_1.s
+++ b/mpn/m88k/mul_1.s
@@ -1,4 +1,4 @@
; mc88100 __mpn_mul_1 -- Multiply a limb vector with a single limb and
; store the product in a second limb vector.
; Copyright (C) 1992, 1994, 1995 Free Software Foundation, Inc.
@@ -50,8 +50,8 @@
text
align 16
- global ___mpn_mul_1
-___mpn_mul_1:
+ global ___gmpn_mul_1
+___gmpn_mul_1:
; Make S1_PTR and RES_PTR point at the end of their blocks
; and negate SIZE.
@@ -1,4 +1,4 @@
-; mc88100 __mpn_mul_1 -- Multiply a limb vector with a single limb and
+; mc88100 __gmpn_mul_1 -- Multiply a limb vector with a single limb and
; store the product in a second limb vector.
; Copyright (C) 1992, 1994, 1995 Free Software Foundation, Inc.